#
# spec file for package a52dec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib       liba52
%define libname   %{lib}-0

Name:           a52dec
Version:        0.8.0
Release:        1.7
Summary:        ATSC A/52 stream decoder library
License:        GPL-2.0-or-later
URL:            https://git.adelielinux.org/community/a52dec/
Source:         https://distfiles.adelielinux.org/source/a52dec/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
BuildRequires:  libtool
BuildRequires:  pkgconfig
Requires:       %{libname} = %{version}
Provides:       a52 = %{version}
Obsoletes:      a52 < %{version}

%description
liba52 is a library for decoding ATSC A/52 streams.

%package -n %{libname}
Summary:        ATSC A/52 stream decoder library
Provides:       %{lib} = %{version}
Obsoletes:      %{lib} < %{version}
Provides:       liba52dec0 = %{version}
Obsoletes:      liba52dec0 < %{version}

%description -n %{libname}
liba52 is a library for decoding ATSC A/52 streams.
Shared library part of a52dec.

%package -n %{lib}-devel
Summary:        Header files for the a52dec library
Requires:       %{libname} = %{version}
Provides:       a52dec-devel = %{version}
Obsoletes:      a52dec-devel < %{version}
Provides:       liba52dec-devel = %{version}
Obsoletes:      liba52dec-devel < %{version}

%description -n %{lib}-devel
Header files and static library for the a52dec library.
Install this package if you want to compile programs using the library.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
	--disable-static \
	--enable-shared \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %{libname}

%files
%license COPYING
%doc README ChangeLog AUTHORS HISTORY NEWS TODO
%{_bindir}/%{name}
%{_bindir}/extract_a52
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/extract_a52.1%{?ext_man}

%files -n %{libname}
%{_libdir}/%{lib}.so.*

%files -n %{lib}-devel
%{_includedir}/%{name}/
%{_libdir}/%{lib}.so
%{_libdir}/pkgconfig/%{lib}.pc

%changelog
* Fri May  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Minor spec cleaning, use ldconfig_scriptlets macro, be more
  explicit in listing of files (use less globs).
* Tue Dec  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.8.0
  * Build system modernization
- Drop altivec.patch (inapplicable)
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Feb 20 2019 schwab@suse.de
- altivec.patch: always use the GNU version of the altivec insns
* Sat Jul 15 2017 zaitor@opensuse.org
- Drop a52dec-compat.diff and mm_accel.h source, not needed with
  the svn checkout we are using.
- Pass --enable-shared to configure, ensure we build the shared
  library.
* Wed Mar 22 2017 jengelh@inai.de
- Trim filler words from descriptions. Improve summaries.
* Wed Mar 22 2017 aloisio@gmx.com
- Add baselibs.conf as source file
* Tue Mar 21 2017 aloisio@gmx.com
- Spec cleanup
* Wed Nov  5 2014 i@margueirte.su
- update latest svn 0.7.5+svn613
* Tue Jan 24 2012 reddwarf@opensuse.org
- fix baselibs.conf
- don't install the INSTALL file
- change license tag to SPDX
- add automake, autoconf and libtool BuildRequires
* Wed Mar  2 2011 reddwarf@opensuse.org
- run spec cleaner
- remove .la files
- add pkg-config BuildRequire so RPM can do its magic
* Sun Jun 20 2010 ludwig.nussel@gmx.de
- provide a52dec-devel for compatibility
* Sat Nov 21 2009 Manfred.Tremmel@iiv.de
- update to svn from videolan
* Fri Aug 21 2009 Manfred.Tremmel@iiv.de
- cleanups where rpmlint wasn't so happy
* Sat Sep 20 2008 Manfred.Tremmel@iiv.de
- rename of the lib packages
* Sun Apr 20 2008 Manfred.Tremmel@iiv.de
- splitted in different packages
* Tue Nov 23 2004 detlef@dreichelt.de
- changes for x86_64:
  - added CFLAGS= -fPIC
* Tue Mar 25 2003 Manfred.Tremmel@iiv.de
- changes to use Packman upload-script
* Sat Feb 22 2003 Manfred.Tremmel@iiv.de
- added --enable-shared
* Wed Feb  5 2003 Manfred.Tremmel@iiv.de
- added german description
- some changes I got from Philipp Thomas <pthomas@suse.de>
* Wed Jul  3 2002 Manfred.Tremmel@iiv.de
- update to Version 0.7.4
* Thu May 30 2002 Manfred.Tremmel@iiv.de
- update to Version 0.7.3
* Sat Dec 29 2001 waldemar@links2linux.de
- first build
